/* ANSI-C code produced by gperf version 3.0.4 */
/* Command-line: gperf -L ANSI-C -E -c -C -n -o -t -k '*' -NfindValue -Hhash_val -Wwordlist_value -D cssvalues.gperf  */

#if !((' ' == 32) && ('!' == 33) && ('"' == 34) && ('#' == 35) \
      && ('%' == 37) && ('&' == 38) && ('\'' == 39) && ('(' == 40) \
      && (')' == 41) && ('*' == 42) && ('+' == 43) && (',' == 44) \
      && ('-' == 45) && ('.' == 46) && ('/' == 47) && ('0' == 48) \
      && ('1' == 49) && ('2' == 50) && ('3' == 51) && ('4' == 52) \
      && ('5' == 53) && ('6' == 54) && ('7' == 55) && ('8' == 56) \
      && ('9' == 57) && (':' == 58) && (';' == 59) && ('<' == 60) \
      && ('=' == 61) && ('>' == 62) && ('?' == 63) && ('A' == 65) \
      && ('B' == 66) && ('C' == 67) && ('D' == 68) && ('E' == 69) \
      && ('F' == 70) && ('G' == 71) && ('H' == 72) && ('I' == 73) \
      && ('J' == 74) && ('K' == 75) && ('L' == 76) && ('M' == 77) \
      && ('N' == 78) && ('O' == 79) && ('P' == 80) && ('Q' == 81) \
      && ('R' == 82) && ('S' == 83) && ('T' == 84) && ('U' == 85) \
      && ('V' == 86) && ('W' == 87) && ('X' == 88) && ('Y' == 89) \
      && ('Z' == 90) && ('[' == 91) && ('\\' == 92) && (']' == 93) \
      && ('^' == 94) && ('_' == 95) && ('a' == 97) && ('b' == 98) \
      && ('c' == 99) && ('d' == 100) && ('e' == 101) && ('f' == 102) \
      && ('g' == 103) && ('h' == 104) && ('i' == 105) && ('j' == 106) \
      && ('k' == 107) && ('l' == 108) && ('m' == 109) && ('n' == 110) \
      && ('o' == 111) && ('p' == 112) && ('q' == 113) && ('r' == 114) \
      && ('s' == 115) && ('t' == 116) && ('u' == 117) && ('v' == 118) \
      && ('w' == 119) && ('x' == 120) && ('y' == 121) && ('z' == 122) \
      && ('{' == 123) && ('|' == 124) && ('}' == 125) && ('~' == 126))
/* The character set is not based on ISO-646.  */
#error "gperf generated tables don't work with this execution character set. Please report a bug to <bug-gnu-gperf@gnu.org>."
#endif

#line 1 "cssvalues.gperf"

/* This file is automatically generated from cssvalues.in by makevalues, do not edit */
/* Copyright 1999 W. Bastian */
#include "cssvalues.h"
#line 6 "cssvalues.gperf"
struct css_value {
    const char *name;
    int id;
};

static const css_value *findValue(register const char *str, register unsigned int len);
/* maximum key range = 2529, duplicates = 0 */

#ifdef __GNUC__
__inline
#else
#ifdef __cplusplus
inline
#endif
#endif
static unsigned int
hash_val(register const char *str, register unsigned int len)
{
    static const unsigned short asso_values[] = {
        2529, 2529, 2529, 2529, 2529, 2529, 2529, 2529, 2529, 2529,
        2529, 2529, 2529, 2529, 2529, 2529, 2529, 2529, 2529, 2529,
        2529, 2529, 2529, 2529, 2529, 2529, 2529, 2529, 2529, 2529,
        2529, 2529,    5, 2529, 2529, 2529, 2529, 2529, 2529, 2529,
        2529, 2529, 2529, 2529, 2529,   80,  125,  190, 2529,    0,
        95,   90,   70,   65,   60,   55,   15,    5, 2529, 2529,
        2529, 2529, 2529, 2529, 2529, 2529,    5, 2529, 2529,    0,
        0,    5,    0, 2529, 2529, 2529,    0, 2529, 2529, 2529,
        0,    0,    5,   10, 2529, 2529, 2529, 2529, 2529, 2529,
        2529, 2529, 2529, 2529, 2529, 2529, 2529,  140,   45,   10,
        135,    5,    3,  410,  205,    5,  368,  258,   55,   15,
        0,   15,    0,  430,  110,   65,    0,   60,  103,  510,
        1,  408,  438,    0, 2529, 2529, 2529, 2529, 2529, 2529,
        2529, 2529, 2529, 2529, 2529, 2529, 2529, 2529, 2529, 2529,
        2529, 2529, 2529, 2529, 2529, 2529, 2529, 2529, 2529, 2529,
        2529, 2529, 2529, 2529, 2529, 2529, 2529, 2529, 2529, 2529,
        2529, 2529, 2529, 2529, 2529, 2529, 2529, 2529, 2529, 2529,
        2529, 2529, 2529, 2529, 2529, 2529, 2529, 2529, 2529, 2529,
        2529, 2529, 2529, 2529, 2529, 2529, 2529, 2529, 2529, 2529,
        2529, 2529, 2529, 2529, 2529, 2529, 2529, 2529, 2529, 2529,
        2529, 2529, 2529, 2529, 2529, 2529, 2529, 2529, 2529, 2529,
        2529, 2529, 2529, 2529, 2529, 2529, 2529, 2529, 2529, 2529,
        2529, 2529, 2529, 2529, 2529, 2529, 2529, 2529, 2529, 2529,
        2529, 2529, 2529, 2529, 2529, 2529, 2529, 2529, 2529, 2529,
        2529, 2529, 2529, 2529, 2529, 2529, 2529, 2529, 2529, 2529,
        2529, 2529, 2529, 2529, 2529, 2529, 2529, 2529
    };
    register int hval = 0;

    switch (len) {
    default:
        hval += asso_values[(unsigned char)str[27]];
    /*FALLTHROUGH*/
    case 27:
        hval += asso_values[(unsigned char)str[26]];
    /*FALLTHROUGH*/
    case 26:
        hval += asso_values[(unsigned char)str[25]];
    /*FALLTHROUGH*/
    case 25:
        hval += asso_values[(unsigned char)str[24]];
    /*FALLTHROUGH*/
    case 24:
        hval += asso_values[(unsigned char)str[23]];
    /*FALLTHROUGH*/
    case 23:
        hval += asso_values[(unsigned char)str[22]];
    /*FALLTHROUGH*/
    case 22:
        hval += asso_values[(unsigned char)str[21]];
    /*FALLTHROUGH*/
    case 21:
        hval += asso_values[(unsigned char)str[20]];
    /*FALLTHROUGH*/
    case 20:
        hval += asso_values[(unsigned char)str[19]];
    /*FALLTHROUGH*/
    case 19:
        hval += asso_values[(unsigned char)str[18]];
    /*FALLTHROUGH*/
    case 18:
        hval += asso_values[(unsigned char)str[17]];
    /*FALLTHROUGH*/
    case 17:
        hval += asso_values[(unsigned char)str[16]];
    /*FALLTHROUGH*/
    case 16:
        hval += asso_values[(unsigned char)str[15]];
    /*FALLTHROUGH*/
    case 15:
        hval += asso_values[(unsigned char)str[14]];
    /*FALLTHROUGH*/
    case 14:
        hval += asso_values[(unsigned char)str[13]];
    /*FALLTHROUGH*/
    case 13:
        hval += asso_values[(unsigned char)str[12]];
    /*FALLTHROUGH*/
    case 12:
        hval += asso_values[(unsigned char)str[11]];
    /*FALLTHROUGH*/
    case 11:
        hval += asso_values[(unsigned char)str[10]];
    /*FALLTHROUGH*/
    case 10:
        hval += asso_values[(unsigned char)str[9]];
    /*FALLTHROUGH*/
    case 9:
        hval += asso_values[(unsigned char)str[8]];
    /*FALLTHROUGH*/
    case 8:
        hval += asso_values[(unsigned char)str[7]];
    /*FALLTHROUGH*/
    case 7:
        hval += asso_values[(unsigned char)str[6]];
    /*FALLTHROUGH*/
    case 6:
        hval += asso_values[(unsigned char)str[5]];
    /*FALLTHROUGH*/
    case 5:
        hval += asso_values[(unsigned char)str[4] + 2];
    /*FALLTHROUGH*/
    case 4:
        hval += asso_values[(unsigned char)str[3]];
    /*FALLTHROUGH*/
    case 3:
        hval += asso_values[(unsigned char)str[2] + 1];
    /*FALLTHROUGH*/
    case 2:
        hval += asso_values[(unsigned char)str[1] + 1];
    /*FALLTHROUGH*/
    case 1:
        hval += asso_values[(unsigned char)str[0]];
        break;
    }
    return hval;
}

#ifdef __GNUC__
__inline
#if defined __GNUC_STDC_INLINE__ || defined __GNUC_GNU_INLINE__
__attribute__((__gnu_inline__))
#endif
#endif
const struct css_value *
findValue(register const char *str, register unsigned int len)
{
    enum {
        TOTAL_KEYWORDS = 336,
        MIN_WORD_LENGTH = 2,
        MAX_WORD_LENGTH = 28,
        MIN_HASH_VALUE = 0,
        MAX_HASH_VALUE = 2528
    };

    static const struct css_value wordlist_value[] = {
#line 40 "cssvalues.gperf"
        {"100", CSS_VAL_100},
#line 48 "cssvalues.gperf"
        {"900", CSS_VAL_900},
#line 349 "cssvalues.gperf"
        {"tb", CSS_VAL_TB},
#line 47 "cssvalues.gperf"
        {"800", CSS_VAL_800},
#line 17 "cssvalues.gperf"
        {"none", CSS_VAL_NONE},
#line 261 "cssvalues.gperf"
        {"embed", CSS_VAL_EMBED},
#line 331 "cssvalues.gperf"
        {"end", CSS_VAL_END},
#line 191 "cssvalues.gperf"
        {"compact", CSS_VAL_COMPACT},
#line 149 "cssvalues.gperf"
        {"inside", CSS_VAL_INSIDE},
#line 14 "cssvalues.gperf"
        {"inherit", CSS_VAL_INHERIT},
#line 306 "cssvalues.gperf"
        {"contain", CSS_VAL_CONTAIN},
#line 187 "cssvalues.gperf"
        {"inline", CSS_VAL_INLINE},
#line 295 "cssvalues.gperf"
        {"fast", CSS_VAL_FAST},
#line 85 "cssvalues.gperf"
        {"indigo", CSS_VAL_INDIGO},
#line 46 "cssvalues.gperf"
        {"700", CSS_VAL_700},
#line 45 "cssvalues.gperf"
        {"600", CSS_VAL_600},
#line 270 "cssvalues.gperf"
        {"lower", CSS_VAL_LOWER},
#line 44 "cssvalues.gperf"
        {"500", CSS_VAL_500},
#line 246 "cssvalues.gperf"
        {"pre", CSS_VAL_PRE},
#line 43 "cssvalues.gperf"
        {"400", CSS_VAL_400},
#line 259 "cssvalues.gperf"
        {"crop", CSS_VAL_CROP},
#line 334 "cssvalues.gperf"
        {"sRGB", CSS_VAL_SRGB},
#line 210 "cssvalues.gperf"
        {"cell", CSS_VAL_CELL},
#line 188 "cssvalues.gperf"
        {"block", CSS_VAL_BLOCK},
#line 25 "cssvalues.gperf"
        {"solid", CSS_VAL_SOLID},
#line 42 "cssvalues.gperf"
        {"300", CSS_VAL_300},
#line 29 "cssvalues.gperf"
        {"menu", CSS_VAL_MENU},
#line 41 "cssvalues.gperf"
        {"200", CSS_VAL_200},
#line 94 "cssvalues.gperf"
        {"teal", CSS_VAL_TEAL},
#line 131 "cssvalues.gperf"
        {"baseline", CSS_VAL_BASELINE},
#line 92 "cssvalues.gperf"
        {"red", CSS_VAL_RED},
#line 347 "cssvalues.gperf"
        {"lr", CSS_VAL_LR},
#line 245 "cssvalues.gperf"
        {"nowrap", CSS_VAL_NOWRAP},
#line 348 "cssvalues.gperf"
        {"rl", CSS_VAL_RL},
#line 19 "cssvalues.gperf"
        {"inset", CSS_VAL_INSET},
#line 79 "cssvalues.gperf"
        {"black", CSS_VAL_BLACK},
#line 90 "cssvalues.gperf"
        {"orange", CSS_VAL_ORANGE},
#line 293 "cssvalues.gperf"
        {"down", CSS_VAL_DOWN},
#line 28 "cssvalues.gperf"
        {"icon", CSS_VAL_ICON},
#line 36 "cssvalues.gperf"
        {"normal", CSS_VAL_NORMAL},
#line 281 "cssvalues.gperf"
        {"underline", CSS_VAL_UNDERLINE},
#line 248 "cssvalues.gperf"
        {"pre-line", CSS_VAL_PRE_LINE},
#line 240 "cssvalues.gperf"
        {"collapse", CSS_VAL_COLLAPSE},
#line 51 "cssvalues.gperf"
        {"small", CSS_VAL_SMALL},
#line 80 "cssvalues.gperf"
        {"blue", CSS_VAL_BLUE},
#line 342 "cssvalues.gperf"
        {"all", CSS_VAL_ALL},
#line 91 "cssvalues.gperf"
        {"purple", CSS_VAL_PURPLE},
#line 34 "cssvalues.gperf"
        {"oblique", CSS_VAL_OBLIQUE},
#line 133 "cssvalues.gperf"
        {"sub", CSS_VAL_SUB},
#line 234 "cssvalues.gperf"
        {"ltr", CSS_VAL_LTR},
#line 235 "cssvalues.gperf"
        {"rtl", CSS_VAL_RTL},
#line 346 "cssvalues.gperf"
        {"tb-lr", CSS_VAL_TB_LR},
#line 37 "cssvalues.gperf"
        {"bold", CSS_VAL_BOLD},
#line 260 "cssvalues.gperf"
        {"cross", CSS_VAL_CROSS},
#line 114 "cssvalues.gperf"
        {"menutext", CSS_VAL_MENUTEXT},
#line 325 "cssvalues.gperf"
        {"butt", CSS_VAL_BUTT},
#line 274 "cssvalues.gperf"
        {"portrait", CSS_VAL_PORTRAIT},
#line 323 "cssvalues.gperf"
        {"round", CSS_VAL_ROUND},
#line 206 "cssvalues.gperf"
        {"help", CSS_VAL_HELP},
#line 341 "cssvalues.gperf"
        {"stroke", CSS_VAL_STROKE},
#line 312 "cssvalues.gperf"
        {"central ", CSS_VAL_CENTRAL },
#line 252 "cssvalues.gperf"
        {"absolute", CSS_VAL_ABSOLUTE},
#line 345 "cssvalues.gperf"
        {"tb-rl", CSS_VAL_TB_RL},
#line 286 "cssvalues.gperf"
        {"enabled", CSS_VAL_ENABLED},
#line 73 "cssvalues.gperf"
        {"monospace", CSS_VAL_MONOSPACE},
#line 50 "cssvalues.gperf"
        {"x-small", CSS_VAL_X_SMALL},
#line 217 "cssvalues.gperf"
        {"no-drop", CSS_VAL_NO_DROP},
#line 57 "cssvalues.gperf"
        {"smaller", CSS_VAL_SMALLER},
#line 238 "cssvalues.gperf"
        {"lowercase", CSS_VAL_LOWERCASE},
#line 301 "cssvalues.gperf"
        {"ellipsis", CSS_VAL_ELLIPSIS},
#line 26 "cssvalues.gperf"
        {"double", CSS_VAL_DOUBLE},
#line 290 "cssvalues.gperf"
        {"ahead", CSS_VAL_AHEAD},
#line 269 "cssvalues.gperf"
        {"loud", CSS_VAL_LOUD},
#line 126 "cssvalues.gperf"
        {"-khtml-text", CSS_VAL__KHTML_TEXT},
#line 258 "cssvalues.gperf"
        {"both", CSS_VAL_BOTH},
#line 203 "cssvalues.gperf"
        {"auto", CSS_VAL_AUTO},
#line 319 "cssvalues.gperf"
        {"use-script", CSS_VAL_USE_SCRIPT},
#line 76 "cssvalues.gperf"
        {"local", CSS_VAL_LOCAL},
#line 74 "cssvalues.gperf"
        {"scroll", CSS_VAL_SCROLL},
#line 178 "cssvalues.gperf"
        {"lower-latin", CSS_VAL_LOWER_LATIN},
#line 69 "cssvalues.gperf"
        {"serif", CSS_VAL_SERIF},
#line 145 "cssvalues.gperf"
        {"-khtml-left", CSS_VAL__KHTML_LEFT},
#line 166 "cssvalues.gperf"
        {"armenian", CSS_VAL_ARMENIAN},
#line 253 "cssvalues.gperf"
        {"always", CSS_VAL_ALWAYS},
#line 298 "cssvalues.gperf"
        {"alternate", CSS_VAL_ALTERNATE},
#line 194 "cssvalues.gperf"
        {"inline-table", CSS_VAL_INLINE_TABLE},
#line 280 "cssvalues.gperf"
        {"thin", CSS_VAL_THIN},
#line 343 "cssvalues.gperf"
        {"lr-tb", CSS_VAL_LR_TB},
#line 330 "cssvalues.gperf"
        {"start", CSS_VAL_START},
#line 344 "cssvalues.gperf"
        {"rl-tb", CSS_VAL_RL_TB},
#line 300 "cssvalues.gperf"
        {"clip", CSS_VAL_CLIP},
#line 279 "cssvalues.gperf"
        {"thick", CSS_VAL_THICK},
#line 262 "cssvalues.gperf"
        {"hand", CSS_VAL_HAND},
#line 212 "cssvalues.gperf"
        {"text", CSS_VAL_TEXT},
#line 31 "cssvalues.gperf"
        {"small-caption", CSS_VAL_SMALL_CAPTION},
#line 147 "cssvalues.gperf"
        {"-khtml-center", CSS_VAL__KHTML_CENTER},
#line 163 "cssvalues.gperf"
        {"lower-roman", CSS_VAL_LOWER_ROMAN},
#line 152 "cssvalues.gperf"
        {"square", CSS_VAL_SQUARE},
#line 77 "cssvalues.gperf"
        {"transparent", CSS_VAL_TRANSPARENT},
#line 86 "cssvalues.gperf"
        {"lime", CSS_VAL_LIME},
#line 137 "cssvalues.gperf"
        {"top", CSS_VAL_TOP},
#line 33 "cssvalues.gperf"
        {"italic", CSS_VAL_ITALIC},
#line 304 "cssvalues.gperf"
        {"content", CSS_VAL_CONTENT},
#line 278 "cssvalues.gperf"
        {"static", CSS_VAL_STATIC},
#line 340 "cssvalues.gperf"
        {"fill", CSS_VAL_FILL},
#line 257 "cssvalues.gperf"
        {"blink", CSS_VAL_BLINK},
#line 296 "cssvalues.gperf"
        {"infinite", CSS_VAL_INFINITE},
#line 322 "cssvalues.gperf"
        {"miter", CSS_VAL_MITER},
#line 153 "cssvalues.gperf"
        {"box", CSS_VAL_BOX},
#line 151 "cssvalues.gperf"
        {"circle", CSS_VAL_CIRCLE},
#line 35 "cssvalues.gperf"
        {"small-caps", CSS_VAL_SMALL_CAPS},
#line 110 "cssvalues.gperf"
        {"inactivecaption", CSS_VAL_INACTIVECAPTION},
#line 266 "cssvalues.gperf"
        {"landscape", CSS_VAL_LANDSCAPE},
#line 111 "cssvalues.gperf"
        {"inactivecaptiontext", CSS_VAL_INACTIVECAPTIONTEXT},
#line 141 "cssvalues.gperf"
        {"left", CSS_VAL_LEFT},
#line 84 "cssvalues.gperf"
        {"green", CSS_VAL_GREEN},
#line 275 "cssvalues.gperf"
        {"relative", CSS_VAL_RELATIVE},
#line 162 "cssvalues.gperf"
        {"-khtml-tibetan", CSS_VAL__KHTML_TIBETAN},
#line 255 "cssvalues.gperf"
        {"below", CSS_VAL_BELOW},
#line 155 "cssvalues.gperf"
        {"decimal", CSS_VAL_DECIMAL},
#line 292 "cssvalues.gperf"
        {"up", CSS_VAL_UP},
#line 78 "cssvalues.gperf"
        {"aqua", CSS_VAL_AQUA},
#line 20 "cssvalues.gperf"
        {"groove", CSS_VAL_GROOVE},
#line 158 "cssvalues.gperf"
        {"-khtml-lao", CSS_VAL__KHTML_LAO},
#line 315 "cssvalues.gperf"
        {"ideographic", CSS_VAL_IDEOGRAPHIC},
#line 140 "cssvalues.gperf"
        {"-khtml-auto", CSS_VAL__KHTML_AUTO},
#line 192 "cssvalues.gperf"
        {"inline-block", CSS_VAL_INLINE_BLOCK},
#line 150 "cssvalues.gperf"
        {"disc", CSS_VAL_DISC},
#line 98 "cssvalues.gperf"
        {"activecaption", CSS_VAL_ACTIVECAPTION},
#line 193 "cssvalues.gperf"
        {"table", CSS_VAL_TABLE},
#line 307 "cssvalues.gperf"
        {"cover", CSS_VAL_COVER},
#line 132 "cssvalues.gperf"
        {"middle", CSS_VAL_MIDDLE},
#line 216 "cssvalues.gperf"
        {"move", CSS_VAL_MOVE},
#line 81 "cssvalues.gperf"
        {"crimson", CSS_VAL_CRIMSON},
#line 265 "cssvalues.gperf"
        {"invert", CSS_VAL_INVERT},
#line 16 "cssvalues.gperf"
        {"-khtml-native", CSS_VAL__KHTML_NATIVE},
#line 72 "cssvalues.gperf"
        {"fantasy", CSS_VAL_FANTASY},
#line 143 "cssvalues.gperf"
        {"center", CSS_VAL_CENTER},
#line 138 "cssvalues.gperf"
        {"bottom", CSS_VAL_BOTTOM},
#line 52 "cssvalues.gperf"
        {"medium", CSS_VAL_MEDIUM},
#line 113 "cssvalues.gperf"
        {"infotext", CSS_VAL_INFOTEXT},
#line 233 "cssvalues.gperf"
        {"all-scroll", CSS_VAL_ALL_SCROLL},
#line 127 "cssvalues.gperf"
        {"repeat", CSS_VAL_REPEAT},
#line 324 "cssvalues.gperf"
        {"bevel", CSS_VAL_BEVEL},
#line 190 "cssvalues.gperf"
        {"run-in", CSS_VAL_RUN_IN},
#line 70 "cssvalues.gperf"
        {"sans-serif", CSS_VAL_SANS_SERIF},
#line 87 "cssvalues.gperf"
        {"maroon", CSS_VAL_MAROON},
#line 267 "cssvalues.gperf"
        {"level", CSS_VAL_LEVEL},
#line 285 "cssvalues.gperf"
        {"content-box", CSS_VAL_CONTENT_BOX},
#line 335 "cssvalues.gperf"
        {"linearRGB", CSS_VAL_LINEARRGB},
#line 277 "cssvalues.gperf"
        {"show", CSS_VAL_SHOW},
#line 263 "cssvalues.gperf"
        {"hide", CSS_VAL_HIDE},
#line 207 "cssvalues.gperf"
        {"pointer", CSS_VAL_POINTER},
#line 294 "cssvalues.gperf"
        {"slow", CSS_VAL_SLOW},
#line 205 "cssvalues.gperf"
        {"context-menu", CSS_VAL_CONTEXT_MENU},
#line 299 "cssvalues.gperf"
        {"unfurl", CSS_VAL_UNFURL},
#line 134 "cssvalues.gperf"
        {"super", CSS_VAL_SUPER},
#line 71 "cssvalues.gperf"
        {"cursive", CSS_VAL_CURSIVE},
#line 208 "cssvalues.gperf"
        {"progress", CSS_VAL_PROGRESS},
#line 159 "cssvalues.gperf"
        {"-khtml-persian", CSS_VAL__KHTML_PERSIAN},
#line 135 "cssvalues.gperf"
        {"text-top", CSS_VAL_TEXT_TOP},
#line 231 "cssvalues.gperf"
        {"col-resize", CSS_VAL_COL_RESIZE},
#line 282 "cssvalues.gperf"
        {"-khtml-normal", CSS_VAL__KHTML_NORMAL},
#line 115 "cssvalues.gperf"
        {"scrollbar", CSS_VAL_SCROLLBAR},
#line 64 "cssvalues.gperf"
        {"semi-condensed", CSS_VAL_SEMI_CONDENSED},
#line 189 "cssvalues.gperf"
        {"list-item", CSS_VAL_LIST_ITEM},
#line 128 "cssvalues.gperf"
        {"repeat-x", CSS_VAL_REPEAT_X},
#line 161 "cssvalues.gperf"
        {"-khtml-thai", CSS_VAL__KHTML_THAI},
#line 148 "cssvalues.gperf"
        {"outside", CSS_VAL_OUTSIDE},
#line 104 "cssvalues.gperf"
        {"buttontext", CSS_VAL_BUTTONTEXT},
#line 273 "cssvalues.gperf"
        {"overline", CSS_VAL_OVERLINE},
#line 30 "cssvalues.gperf"
        {"message-box", CSS_VAL_MESSAGE_BOX},
#line 82 "cssvalues.gperf"
        {"fuchsia", CSS_VAL_FUCHSIA},
#line 22 "cssvalues.gperf"
        {"outset", CSS_VAL_OUTSET},
#line 160 "cssvalues.gperf"
        {"-khtml-urdu", CSS_VAL__KHTML_URDU},
#line 339 "cssvalues.gperf"
        {"painted", CSS_VAL_PAINTED},
#line 254 "cssvalues.gperf"
        {"avoid", CSS_VAL_AVOID},
#line 211 "cssvalues.gperf"
        {"crosshair", CSS_VAL_CROSSHAIR},
#line 251 "cssvalues.gperf"
        {"above", CSS_VAL_ABOVE},
#line 239 "cssvalues.gperf"
        {"visible", CSS_VAL_VISIBLE},
#line 167 "cssvalues.gperf"
        {"georgian", CSS_VAL_GEORGIAN},
#line 177 "cssvalues.gperf"
        {"lower-alpha", CSS_VAL_LOWER_ALPHA},
#line 65 "cssvalues.gperf"
        {"semi-expanded", CSS_VAL_SEMI_EXPANDED},
#line 136 "cssvalues.gperf"
        {"text-bottom", CSS_VAL_TEXT_BOTTOM},
#line 54 "cssvalues.gperf"
        {"x-large", CSS_VAL_X_LARGE},
#line 291 "cssvalues.gperf"
        {"reverse", CSS_VAL_REVERSE},
#line 220 "cssvalues.gperf"
        {"n-resize", CSS_VAL_N_RESIZE},
#line 61 "cssvalues.gperf"
        {"ultra-condensed", CSS_VAL_ULTRA_CONDENSED},
#line 219 "cssvalues.gperf"
        {"e-resize", CSS_VAL_E_RESIZE},
#line 232 "cssvalues.gperf"
        {"row-resize", CSS_VAL_ROW_RESIZE},
#line 109 "cssvalues.gperf"
        {"inactiveborder", CSS_VAL_INACTIVEBORDER},
#line 38 "cssvalues.gperf"
        {"bolder", CSS_VAL_BOLDER},
#line 213 "cssvalues.gperf"
        {"vertical-text", CSS_VAL_VERTICAL_TEXT},
#line 214 "cssvalues.gperf"
        {"alias", CSS_VAL_ALIAS},
#line 201 "cssvalues.gperf"
        {"table-cell", CSS_VAL_TABLE_CELL},
#line 154 "cssvalues.gperf"
        {"-khtml-diamond", CSS_VAL__KHTML_DIAMOND},
#line 23 "cssvalues.gperf"
        {"dotted", CSS_VAL_DOTTED},
#line 326 "cssvalues.gperf"
        {"accumulate", CSS_VAL_ACCUMULATE},
#line 200 "cssvalues.gperf"
        {"table-column", CSS_VAL_TABLE_COLUMN},
#line 68 "cssvalues.gperf"
        {"ultra-expanded", CSS_VAL_ULTRA_EXPANDED},
#line 27 "cssvalues.gperf"
        {"caption", CSS_VAL_CAPTION},
#line 105 "cssvalues.gperf"
        {"captiontext", CSS_VAL_CAPTIONTEXT},
#line 303 "cssvalues.gperf"
        {"border", CSS_VAL_BORDER},
#line 97 "cssvalues.gperf"
        {"activeborder", CSS_VAL_ACTIVEBORDER},
#line 223 "cssvalues.gperf"
        {"s-resize", CSS_VAL_S_RESIZE},
#line 202 "cssvalues.gperf"
        {"table-caption", CSS_VAL_TABLE_CAPTION},
#line 63 "cssvalues.gperf"
        {"condensed", CSS_VAL_CONDENSED},
#line 117 "cssvalues.gperf"
        {"threedface", CSS_VAL_THREEDFACE},
#line 276 "cssvalues.gperf"
        {"separate", CSS_VAL_SEPARATE},
#line 337 "cssvalues.gperf"
        {"visibleFill", CSS_VAL_VISIBLEFILL},
#line 75 "cssvalues.gperf"
        {"fixed", CSS_VAL_FIXED},
#line 130 "cssvalues.gperf"
        {"no-repeat", CSS_VAL_NO_REPEAT},
#line 272 "cssvalues.gperf"
        {"mix", CSS_VAL_MIX},
#line 101 "cssvalues.gperf"
        {"buttonface", CSS_VAL_BUTTONFACE},
#line 182 "cssvalues.gperf"
        {"katakana", CSS_VAL_KATAKANA},
#line 247 "cssvalues.gperf"
        {"pre-wrap", CSS_VAL_PRE_WRAP},
#line 100 "cssvalues.gperf"
        {"background", CSS_VAL_BACKGROUND},
#line 242 "cssvalues.gperf"
        {"no-close-quote", CSS_VAL_NO_CLOSE_QUOTE},
#line 321 "cssvalues.gperf"
        {"reset-size", CSS_VAL_RESET_SIZE},
#line 230 "cssvalues.gperf"
        {"nwse-resize", CSS_VAL_NWSE_RESIZE},
#line 15 "cssvalues.gperf"
        {"initial", CSS_VAL_INITIAL},
#line 243 "cssvalues.gperf"
        {"no-open-quote", CSS_VAL_NO_OPEN_QUOTE},
#line 215 "cssvalues.gperf"
        {"copy", CSS_VAL_COPY},
#line 305 "cssvalues.gperf"
        {"padding", CSS_VAL_PADDING},
#line 49 "cssvalues.gperf"
        {"xx-small", CSS_VAL_XX_SMALL},
#line 316 "cssvalues.gperf"
        {"alphabetic", CSS_VAL_ALPHABETIC},
#line 125 "cssvalues.gperf"
        {"grey", CSS_VAL_GREY},
#line 59 "cssvalues.gperf"
        {"wider", CSS_VAL_WIDER},
#line 288 "cssvalues.gperf"
        {"forwards", CSS_VAL_FORWARDS},
#line 185 "cssvalues.gperf"
        {"-khtml-open-quote", CSS_VAL__KHTML_OPEN_QUOTE},
#line 124 "cssvalues.gperf"
        {"currentcolor", CSS_VAL_CURRENTCOLOR},
#line 284 "cssvalues.gperf"
        {"border-box", CSS_VAL_BORDER_BOX},
#line 89 "cssvalues.gperf"
        {"olive", CSS_VAL_OLIVE},
#line 209 "cssvalues.gperf"
        {"wait", CSS_VAL_WAIT},
#line 218 "cssvalues.gperf"
        {"not-allowed", CSS_VAL_NOT_ALLOWED},
#line 83 "cssvalues.gperf"
        {"gray", CSS_VAL_GRAY},
#line 175 "cssvalues.gperf"
        {"lower-greek", CSS_VAL_LOWER_GREEK},
#line 24 "cssvalues.gperf"
        {"dashed", CSS_VAL_DASHED},
#line 336 "cssvalues.gperf"
        {"visiblePainted", CSS_VAL_VISIBLEPAINTED},
#line 88 "cssvalues.gperf"
        {"navy", CSS_VAL_NAVY},
#line 287 "cssvalues.gperf"
        {"disabled", CSS_VAL_DISABLED},
#line 157 "cssvalues.gperf"
        {"-khtml-arabic-indic", CSS_VAL__KHTML_ARABIC_INDIC},
#line 53 "cssvalues.gperf"
        {"large", CSS_VAL_LARGE},
#line 309 "cssvalues.gperf"
        {"nonzero", CSS_VAL_NONZERO},
#line 142 "cssvalues.gperf"
        {"right", CSS_VAL_RIGHT},
#line 297 "cssvalues.gperf"
        {"slide", CSS_VAL_SLIDE},
#line 302 "cssvalues.gperf"
        {"padding-box", CSS_VAL_PADDING_BOX},
#line 146 "cssvalues.gperf"
        {"-khtml-right", CSS_VAL__KHTML_RIGHT},
#line 186 "cssvalues.gperf"
        {"-khtml-close-quote", CSS_VAL__KHTML_CLOSE_QUOTE},
#line 106 "cssvalues.gperf"
        {"graytext", CSS_VAL_GRAYTEXT},
#line 139 "cssvalues.gperf"
        {"-khtml-baseline-middle", CSS_VAL__KHTML_BASELINE_MIDDLE},
#line 62 "cssvalues.gperf"
        {"extra-condensed", CSS_VAL_EXTRA_CONDENSED},
#line 129 "cssvalues.gperf"
        {"repeat-y", CSS_VAL_REPEAT_Y},
#line 39 "cssvalues.gperf"
        {"lighter", CSS_VAL_LIGHTER},
#line 320 "cssvalues.gperf"
        {"no-change", CSS_VAL_NO_CHANGE},
#line 181 "cssvalues.gperf"
        {"hiragana", CSS_VAL_HIRAGANA},
#line 249 "cssvalues.gperf"
        {"-khtml-nowrap", CSS_VAL__KHTML_NOWRAP},
#line 338 "cssvalues.gperf"
        {"visibleStroke", CSS_VAL_VISIBLESTROKE},
#line 93 "cssvalues.gperf"
        {"silver", CSS_VAL_SILVER},
#line 271 "cssvalues.gperf"
        {"marquee", CSS_VAL_MARQUEE},
#line 241 "cssvalues.gperf"
        {"close-quote", CSS_VAL_CLOSE_QUOTE},
#line 56 "cssvalues.gperf"
        {"-khtml-xxx-large", CSS_VAL__KHTML_XXX_LARGE},
#line 67 "cssvalues.gperf"
        {"extra-expanded", CSS_VAL_EXTRA_EXPANDED},
#line 58 "cssvalues.gperf"
        {"larger", CSS_VAL_LARGER},
#line 256 "cssvalues.gperf"
        {"bidi-override", CSS_VAL_BIDI_OVERRIDE},
#line 318 "cssvalues.gperf"
        {"mathematical ", CSS_VAL_MATHEMATICAL },
#line 283 "cssvalues.gperf"
        {"-khtml-around-floats", CSS_VAL__KHTML_AROUND_FLOATS},
#line 310 "cssvalues.gperf"
        {"before-edge", CSS_VAL_BEFORE_EDGE},
#line 250 "cssvalues.gperf"
        {"break-word", CSS_VAL_BREAK_WORD},
#line 32 "cssvalues.gperf"
        {"status-bar", CSS_VAL_STATUS_BAR},
#line 18 "cssvalues.gperf"
        {"hidden", CSS_VAL_HIDDEN},
#line 55 "cssvalues.gperf"
        {"xx-large", CSS_VAL_XX_LARGE},
#line 327 "cssvalues.gperf"
        {"optimizeSpeed", CSS_VAL_OPTIMIZESPEED},
#line 144 "cssvalues.gperf"
        {"justify", CSS_VAL_JUSTIFY},
#line 237 "cssvalues.gperf"
        {"uppercase", CSS_VAL_UPPERCASE},
#line 244 "cssvalues.gperf"
        {"open-quote", CSS_VAL_OPEN_QUOTE},
#line 228 "cssvalues.gperf"
        {"ns-resize", CSS_VAL_NS_RESIZE},
#line 222 "cssvalues.gperf"
        {"nw-resize", CSS_VAL_NW_RESIZE},
#line 221 "cssvalues.gperf"
        {"ne-resize", CSS_VAL_NE_RESIZE},
#line 227 "cssvalues.gperf"
        {"ew-resize", CSS_VAL_EW_RESIZE},
#line 171 "cssvalues.gperf"
        {"-khtml-simp-chinese-formal", CSS_VAL__KHTML_SIMP_CHINESE_FORMAL},
#line 172 "cssvalues.gperf"
        {"-khtml-simp-chinese-informal", CSS_VAL__KHTML_SIMP_CHINESE_INFORMAL},
#line 329 "cssvalues.gperf"
        {"geometricPrecision", CSS_VAL_GEOMETRICPRECISION},
#line 180 "cssvalues.gperf"
        {"upper-latin", CSS_VAL_UPPER_LATIN},
#line 226 "cssvalues.gperf"
        {"w-resize", CSS_VAL_W_RESIZE},
#line 308 "cssvalues.gperf"
        {"evenodd", CSS_VAL_EVENODD},
#line 225 "cssvalues.gperf"
        {"sw-resize", CSS_VAL_SW_RESIZE},
#line 224 "cssvalues.gperf"
        {"se-resize", CSS_VAL_SE_RESIZE},
#line 328 "cssvalues.gperf"
        {"crispEdges", CSS_VAL_CRISPEDGES},
#line 198 "cssvalues.gperf"
        {"table-row", CSS_VAL_TABLE_ROW},
#line 236 "cssvalues.gperf"
        {"capitalize", CSS_VAL_CAPITALIZE},
#line 165 "cssvalues.gperf"
        {"hebrew", CSS_VAL_HEBREW},
#line 313 "cssvalues.gperf"
        {"after-edge", CSS_VAL_AFTER_EDGE},
#line 204 "cssvalues.gperf"
        {"default", CSS_VAL_DEFAULT},
#line 66 "cssvalues.gperf"
        {"expanded", CSS_VAL_EXPANDED},
#line 60 "cssvalues.gperf"
        {"narrower", CSS_VAL_NARROWER},
#line 164 "cssvalues.gperf"
        {"upper-roman", CSS_VAL_UPPER_ROMAN},
#line 95 "cssvalues.gperf"
        {"white", CSS_VAL_WHITE},
#line 21 "cssvalues.gperf"
        {"ridge", CSS_VAL_RIDGE},
#line 229 "cssvalues.gperf"
        {"nesw-resize", CSS_VAL_NESW_RESIZE},
#line 176 "cssvalues.gperf"
        {"-khtml-upper-greek", CSS_VAL__KHTML_UPPER_GREEK},
#line 289 "cssvalues.gperf"
        {"backwards", CSS_VAL_BACKWARDS},
#line 317 "cssvalues.gperf"
        {"hanging", CSS_VAL_HANGING},
#line 184 "cssvalues.gperf"
        {"katakana-iroha", CSS_VAL_KATAKANA_IROHA},
#line 311 "cssvalues.gperf"
        {"text-before-edge", CSS_VAL_TEXT_BEFORE_EDGE},
#line 96 "cssvalues.gperf"
        {"yellow", CSS_VAL_YELLOW},
#line 197 "cssvalues.gperf"
        {"table-footer-group", CSS_VAL_TABLE_FOOTER_GROUP},
#line 199 "cssvalues.gperf"
        {"table-column-group", CSS_VAL_TABLE_COLUMN_GROUP},
#line 169 "cssvalues.gperf"
        {"-khtml-japanese-formal", CSS_VAL__KHTML_JAPANESE_FORMAL},
#line 170 "cssvalues.gperf"
        {"-khtml-japanese-informal", CSS_VAL__KHTML_JAPANESE_INFORMAL},
#line 173 "cssvalues.gperf"
        {"-khtml-trad-chinese-formal", CSS_VAL__KHTML_TRAD_CHINESE_FORMAL},
#line 174 "cssvalues.gperf"
        {"-khtml-trad-chinese-informal", CSS_VAL__KHTML_TRAD_CHINESE_INFORMAL},
#line 314 "cssvalues.gperf"
        {"text-after-edge", CSS_VAL_TEXT_AFTER_EDGE},
#line 264 "cssvalues.gperf"
        {"higher", CSS_VAL_HIGHER},
#line 179 "cssvalues.gperf"
        {"upper-alpha", CSS_VAL_UPPER_ALPHA},
#line 107 "cssvalues.gperf"
        {"highlight", CSS_VAL_HIGHLIGHT},
#line 108 "cssvalues.gperf"
        {"highlighttext", CSS_VAL_HIGHLIGHTTEXT},
#line 183 "cssvalues.gperf"
        {"hiragana-iroha", CSS_VAL_HIRAGANA_IROHA},
#line 268 "cssvalues.gperf"
        {"line-through", CSS_VAL_LINE_THROUGH},
#line 333 "cssvalues.gperf"
        {"optimizeQuality", CSS_VAL_OPTIMIZEQUALITY},
#line 120 "cssvalues.gperf"
        {"threedshadow", CSS_VAL_THREEDSHADOW},
#line 168 "cssvalues.gperf"
        {"cjk-ideographic", CSS_VAL_CJK_IDEOGRAPHIC},
#line 103 "cssvalues.gperf"
        {"buttonshadow", CSS_VAL_BUTTONSHADOW},
#line 112 "cssvalues.gperf"
        {"infobackground", CSS_VAL_INFOBACKGROUND},
#line 196 "cssvalues.gperf"
        {"table-header-group", CSS_VAL_TABLE_HEADER_GROUP},
#line 195 "cssvalues.gperf"
        {"table-row-group", CSS_VAL_TABLE_ROW_GROUP},
#line 332 "cssvalues.gperf"
        {"optimizeLegibility", CSS_VAL_OPTIMIZELEGIBILITY},
#line 156 "cssvalues.gperf"
        {"decimal-leading-zero", CSS_VAL_DECIMAL_LEADING_ZERO},
#line 121 "cssvalues.gperf"
        {"window", CSS_VAL_WINDOW},
#line 123 "cssvalues.gperf"
        {"windowtext", CSS_VAL_WINDOWTEXT},
#line 118 "cssvalues.gperf"
        {"threedhighlight", CSS_VAL_THREEDHIGHLIGHT},
#line 102 "cssvalues.gperf"
        {"buttonhighlight", CSS_VAL_BUTTONHIGHLIGHT},
#line 122 "cssvalues.gperf"
        {"windowframe", CSS_VAL_WINDOWFRAME},
#line 116 "cssvalues.gperf"
        {"threeddarkshadow", CSS_VAL_THREEDDARKSHADOW},
#line 119 "cssvalues.gperf"
        {"threedlightshadow", CSS_VAL_THREEDLIGHTSHADOW},
#line 99 "cssvalues.gperf"
        {"appworkspace", CSS_VAL_APPWORKSPACE}
    };

    static const short lookup[] = {
        0,  -1,  -1,  -1,  -1,   1,  -1,  -1,  -1,  -1,
        2,  -1,  -1,  -1,  -1,   3,  -1,  -1,  -1,  -1,
        4,  -1,  -1,   5,  -1,   6,  -1,  -1,  -1,  -1,
        7,  -1,  -1,   8,  -1,   9,  -1,  -1,  -1,  -1,
        10,  -1,  -1,  -1,  -1,  11,  -1,  -1,  12,  -1,
        13,  -1,  -1,  -1,  -1,  14,  -1,  -1,  -1,  -1,
        15,  16,  -1,  -1,  -1,  17,  -1,  -1,  18,  -1,
        19,  -1,  -1,  -1,  -1,  20,  -1,  -1,  -1,  -1,
        21,  -1,  -1,  22,  -1,  23,  -1,  -1,  24,  -1,
        25,  -1,  -1,  26,  -1,  27,  -1,  -1,  -1,  -1,
        -1,  -1,  -1,  28,  -1,  29,  -1,  -1,  -1,  -1,
        -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  30,  -1,
        31,  32,  -1,  -1,  -1,  33,  -1,  -1,  34,  -1,
        35,  -1,  -1,  -1,  -1,  36,  37,  -1,  -1,  -1,
        38,  -1,  -1,  -1,  -1,  39,  -1,  -1,  -1,  -1,
        40,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  41,  -1,
        42,  -1,  -1,  -1,  -1,  43,  -1,  -1,  44,  -1,
        45,  -1,  -1,  46,  -1,  47,  -1,  -1,  48,  -1,
        49,  -1,  -1,  -1,  -1,  50,  -1,  -1,  -1,  -1,
        51,  -1,  -1,  -1,  -1,  52,  -1,  -1,  -1,  -1,
        53,  -1,  54,  -1,  -1,  -1,  -1,  -1,  55,  -1,
        56,  -1,  -1,  -1,  -1,  -1,  57,  -1,  -1,  -1,
        -1,  -1,  -1,  58,  -1,  59,  -1,  -1,  60,  -1,
        61,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,
        -1,  -1,  -1,  -1,  -1,  62,  -1,  -1,  -1,  -1,
        63,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,
        64,  65,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,
        -1,  -1,  -1,  -1,  -1,  66,  -1,  -1,  -1,  -1,
        67,  68,  -1,  -1,  -1,  69,  -1,  -1,  70,  -1,
        -1,  71,  -1,  72,  -1,  -1,  73,  -1,  -1,  -1,
        -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,
        74,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  75,  -1,
        -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  76,  -1,
        77,  -1,  -1,  -1,  -1,  78,  -1,  -1,  -1,  -1,
        -1,  79,  -1,  80,  -1,  -1,  -1,  -1,  -1,  -1,
        -1,  -1,  -1,  81,  -1,  82,  -1,  -1,  -1,  -1,
        -1,  83,  -1,  -1,  -1,  84,  -1,  -1,  -1,  -1,
        85,  -1,  -1,  86,  -1,  -1,  -1,  -1,  -1,  -1,
        87,  -1,  -1,  88,  -1,  89,  -1,  -1,  -1,  -1,
        -1,  -1,  -1,  90,  -1,  -1,  -1,  -1,  91,  -1,
        92,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,
        -1,  93,  -1,  -1,  -1,  94,  -1,  -1,  -1,  -1,
        95,  96,  -1,  97,  -1,  98,  -1,  -1,  99,  -1,
        100,  -1,  -1, 101,  -1, 102,  -1,  -1, 103,  -1,
        -1, 104,  -1, 105,  -1, 106,  -1,  -1, 107,  -1,
        -1,  -1,  -1, 108,  -1,  -1,  -1,  -1, 109,  -1,
        110, 111,  -1,  -1,  -1, 112,  -1, 113, 114,  -1,
        -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,
        -1,  -1,  -1, 115, 116, 117, 118,  -1, 119,  -1,
        120,  -1,  -1, 121,  -1,  -1, 122,  -1,  -1,  -1,
        123,  -1,  -1, 124,  -1, 125,  -1,  -1, 126,  -1,
        -1,  -1,  -1, 127,  -1,  -1, 128,  -1,  -1,  -1,
        129,  -1,  -1,  -1,  -1, 130,  -1,  -1, 131,  -1,
        132,  -1,  -1, 133,  -1, 134,  -1,  -1,  -1,  -1,
        -1,  -1,  -1, 135,  -1,  -1, 136,  -1, 137,  -1,
        138,  -1,  -1, 139, 140, 141,  -1,  -1, 142,  -1,
        -1,  -1,  -1, 143,  -1,  -1, 144,  -1, 145,  -1,
        146,  -1,  -1, 147,  -1,  -1, 148,  -1, 149,  -1,
        150,  -1,  -1, 151,  -1,  -1, 152,  -1,  -1,  -1,
        153,  -1,  -1,  -1,  -1,  -1, 154,  -1,  -1,  -1,
        155,  -1,  -1, 156,  -1,  -1,  -1,  -1,  -1, 157,
        158,  -1,  -1,  -1,  -1, 159, 160,  -1,  -1,  -1,
        -1,  -1,  -1, 161,  -1, 162,  -1,  -1,  -1,  -1,
        163,  -1,  -1, 164,  -1,  -1,  -1,  -1, 165, 166,
        167, 168,  -1,  -1, 169,  -1,  -1,  -1, 170, 171,
        -1, 172,  -1, 173,  -1, 174, 175,  -1, 176,  -1,
        177,  -1,  -1, 178,  -1,  -1,  -1,  -1,  -1,  -1,
        -1, 179,  -1, 180,  -1,  -1,  -1,  -1,  -1,  -1,
        -1, 181,  -1,  -1, 182,  -1,  -1,  -1,  -1,  -1,
        -1, 183,  -1,  -1,  -1,  -1, 184,  -1, 185,  -1,
        -1,  -1,  -1, 186,  -1, 187,  -1,  -1, 188, 189,
        -1, 190,  -1,  -1,  -1, 191,  -1,  -1,  -1,  -1,
        192,  -1,  -1, 193,  -1, 194,  -1,  -1,  -1,  -1,
        -1,  -1,  -1,  -1,  -1, 195,  -1,  -1,  -1,  -1,
        196,  -1,  -1,  -1,  -1, 197,  -1,  -1,  -1,  -1,
        -1,  -1,  -1,  -1,  -1, 198, 199,  -1, 200,  -1,
        -1,  -1,  -1,  -1, 201, 202, 203,  -1, 204,  -1,
        205,  -1,  -1,  -1,  -1, 206,  -1,  -1, 207,  -1,
        -1,  -1,  -1, 208,  -1,  -1, 209, 210,  -1,  -1,
        211, 212,  -1,  -1,  -1,  -1, 213,  -1, 214,  -1,
        -1,  -1,  -1,  -1,  -1,  -1, 215,  -1, 216,  -1,
        217,  -1,  -1,  -1, 218,  -1,  -1,  -1,  -1,  -1,
        -1,  -1,  -1,  -1, 219,  -1,  -1,  -1,  -1,  -1,
        -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,
        -1, 220,  -1,  -1,  -1, 221,  -1,  -1, 222,  -1,
        -1,  -1,  -1, 223,  -1,  -1,  -1,  -1,  -1,  -1,
        -1,  -1,  -1,  -1, 224, 225,  -1,  -1,  -1,  -1,
        -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,
        -1,  -1,  -1,  -1,  -1,  -1, 226,  -1, 227,  -1,
        -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1, 228,  -1,
        229,  -1,  -1, 230,  -1,  -1, 231,  -1,  -1,  -1,
        -1, 232,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,
        -1,  -1,  -1, 233,  -1, 234,  -1,  -1, 235, 236,
        237,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,
        -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,
        -1,  -1,  -1,  -1,  -1,  -1, 238,  -1,  -1,  -1,
        -1,  -1,  -1, 239,  -1,  -1,  -1,  -1,  -1,  -1,
        -1,  -1,  -1, 240,  -1, 241,  -1,  -1,  -1,  -1,
        -1,  -1,  -1,  -1,  -1, 242,  -1,  -1, 243,  -1,
        -1, 244,  -1, 245, 246,  -1,  -1,  -1,  -1,  -1,
        -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,
        -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,
        247,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,
        248,  -1,  -1,  -1,  -1,  -1,  -1, 249,  -1,  -1,
        250,  -1,  -1, 251,  -1,  -1, 252,  -1,  -1,  -1,
        -1, 253,  -1,  -1,  -1,  -1,  -1,  -1, 254,  -1,
        -1,  -1,  -1, 255,  -1, 256,  -1,  -1,  -1, 257,
        -1, 258,  -1,  -1,  -1, 259,  -1,  -1,  -1,  -1,
        -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,
        260,  -1,  -1, 261, 262, 263,  -1,  -1,  -1,  -1,
        -1, 264,  -1,  -1,  -1, 265,  -1,  -1, 266,  -1,
        -1,  -1,  -1, 267,  -1,  -1,  -1,  -1, 268,  -1,
        269,  -1,  -1, 270, 271,  -1,  -1,  -1, 272,  -1,
        -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,
        273,  -1,  -1,  -1,  -1, 274,  -1,  -1, 275,  -1,
        -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1, 276, 277,
        -1, 278,  -1,  -1, 279,  -1,  -1,  -1, 280,  -1,
        -1,  -1,  -1, 281,  -1,  -1,  -1,  -1, 282,  -1,
        -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,
        -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,
        -1,  -1,  -1,  -1,  -1, 283,  -1,  -1,  -1,  -1,
        -1,  -1,  -1, 284,  -1,  -1,  -1,  -1, 285,  -1,
        -1,  -1,  -1,  -1, 286,  -1, 287,  -1,  -1,  -1,
        -1,  -1,  -1, 288,  -1, 289, 290,  -1,  -1,  -1,
        -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1, 291,  -1,
        292,  -1,  -1, 293,  -1,  -1,  -1,  -1, 294,  -1,
        -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,
        -1,  -1,  -1,  -1,  -1, 295,  -1,  -1,  -1,  -1,
        -1,  -1,  -1,  -1,  -1, 296,  -1,  -1,  -1,  -1,
        -1,  -1,  -1, 297,  -1,  -1,  -1,  -1,  -1,  -1,
        -1,  -1,  -1, 298,  -1,  -1,  -1,  -1,  -1,  -1,
        -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,
        -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,
        -1, 299,  -1, 300,  -1,  -1,  -1,  -1,  -1,  -1,
        -1, 301,  -1, 302,  -1,  -1,  -1,  -1,  -1,  -1,
        -1,  -1,  -1, 303,  -1,  -1,  -1,  -1,  -1,  -1,
        -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,
        -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,
        -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,
        -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,
        -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,
        -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1, 304,
        -1, 305,  -1, 306,  -1,  -1,  -1,  -1,  -1,  -1,
        307, 308,  -1,  -1,  -1,  -1, 309,  -1,  -1,  -1,
        -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,
        -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,
        -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1, 310,  -1,
        -1,  -1,  -1, 311,  -1,  -1,  -1,  -1,  -1,  -1,
        -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,
        -1,  -1,  -1,  -1, 312,  -1,  -1,  -1,  -1,  -1,
        -1,  -1,  -1, 313,  -1,  -1,  -1,  -1,  -1,  -1,
        -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,
        -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,
        -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,
        -1,  -1,  -1,  -1,  -1, 314,  -1,  -1,  -1,  -1,
        -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,
        -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,
        -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,
        -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,
        -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,
        -1,  -1,  -1, 315,  -1,  -1,  -1,  -1,  -1, 316,
        -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1, 317,  -1,
        -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,
        -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1, 318,  -1,
        -1, 319,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,
        -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,
        -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,
        -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,
        -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,
        320,  -1,  -1,  -1,  -1,  -1, 321,  -1,  -1,  -1,
        -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1, 322,  -1,
        -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1, 323,  -1,
        -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,
        -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,
        -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,
        -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,
        -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,
        -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,
        -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,
        -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,
        -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,
        -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,
        -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,
        -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,
        -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,
        -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,
        -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,
        -1,  -1,  -1,  -1,  -1, 324,  -1,  -1,  -1,  -1,
        -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,
        -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,
        -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,
        325, 326,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,
        -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,
        -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,
        -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,
        -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,
        -1,  -1,  -1,  -1,  -1,  -1, 327,  -1, 328,  -1,
        -1,  -1,  -1,  -1, 329,  -1,  -1,  -1,  -1,  -1,
        -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,
        -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,
        -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,
        -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,
        -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,
        -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,
        -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,
        -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,
        -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,
        -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,
        -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,
        -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,
        -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,
        -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,
        330,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,
        -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1, 331,  -1,
        -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,
        -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,
        -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,
        -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,
        -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,
        -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,
        -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,
        -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,
        -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,
        -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,
        -1, 332,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,
        -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,
        -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,
        -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,
        -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,
        -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,
        -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,
        -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,
        -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,
        -1,  -1,  -1, 333,  -1,  -1,  -1,  -1,  -1,  -1,
        -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,
        -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,
        -1,  -1,  -1,  -1,  -1, 334,  -1,  -1,  -1,  -1,
        -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,
        -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,
        -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,
        -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,
        -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,
        -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,
        -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,
        -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,
        -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,
        -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,
        -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,
        -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,
        -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,
        -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,
        -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,
        -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1, 335
    };

    if (len <= MAX_WORD_LENGTH && len >= MIN_WORD_LENGTH) {
        register int key = hash_val(str, len);

        if (key <= MAX_HASH_VALUE && key >= 0) {
            register int index = lookup[key];

            if (index >= 0) {
                register const char *s = wordlist_value[index].name;

                if (*str == *s && !strncmp(str + 1, s + 1, len - 1) && s[len] == '\0') {
                    return &wordlist_value[index];
                }
            }
        }
    }
    return 0;
}
#line 350 "cssvalues.gperf"

static const char *const valueList[] = {
    "",
    "inherit",
    "initial",
    "-khtml-native",
    "none",
    "hidden",
    "inset",
    "groove",
    "ridge",
    "outset",
    "dotted",
    "dashed",
    "solid",
    "double",
    "caption",
    "icon",
    "menu",
    "message-box",
    "small-caption",
    "status-bar",
    "italic",
    "oblique",
    "small-caps",
    "normal",
    "bold",
    "bolder",
    "lighter",
    "100",
    "200",
    "300",
    "400",
    "500",
    "600",
    "700",
    "800",
    "900",
    "xx-small",
    "x-small",
    "small",
    "medium",
    "large",
    "x-large",
    "xx-large",
    "-khtml-xxx-large",
    "smaller",
    "larger",
    "wider",
    "narrower",
    "ultra-condensed",
    "extra-condensed",
    "condensed",
    "semi-condensed",
    "semi-expanded",
    "expanded",
    "extra-expanded",
    "ultra-expanded",
    "serif",
    "sans-serif",
    "cursive",
    "fantasy",
    "monospace",
    "scroll",
    "fixed",
    "local",
    "transparent",
    "aqua",
    "black",
    "blue",
    "crimson",
    "fuchsia",
    "gray",
    "green",
    "indigo",
    "lime",
    "maroon",
    "navy",
    "olive",
    "orange",
    "purple",
    "red",
    "silver",
    "teal",
    "white",
    "yellow",
    "activeborder",
    "activecaption",
    "appworkspace",
    "background",
    "buttonface",
    "buttonhighlight",
    "buttonshadow",
    "buttontext",
    "captiontext",
    "graytext",
    "highlight",
    "highlighttext",
    "inactiveborder",
    "inactivecaption",
    "inactivecaptiontext",
    "infobackground",
    "infotext",
    "menutext",
    "scrollbar",
    "threeddarkshadow",
    "threedface",
    "threedhighlight",
    "threedlightshadow",
    "threedshadow",
    "window",
    "windowframe",
    "windowtext",
    "currentcolor",
    "grey",
    "-khtml-text",
    "repeat",
    "repeat-x",
    "repeat-y",
    "no-repeat",
    "baseline",
    "middle",
    "sub",
    "super",
    "text-top",
    "text-bottom",
    "top",
    "bottom",
    "-khtml-baseline-middle",
    "-khtml-auto",
    "left",
    "right",
    "center",
    "justify",
    "-khtml-left",
    "-khtml-right",
    "-khtml-center",
    "outside",
    "inside",
    "disc",
    "circle",
    "square",
    "box",
    "-khtml-diamond",
    "decimal",
    "decimal-leading-zero",
    "-khtml-arabic-indic",
    "-khtml-lao",
    "-khtml-persian",
    "-khtml-urdu",
    "-khtml-thai",
    "-khtml-tibetan",
    "lower-roman",
    "upper-roman",
    "hebrew",
    "armenian",
    "georgian",
    "cjk-ideographic",
    "-khtml-japanese-formal",
    "-khtml-japanese-informal",
    "-khtml-simp-chinese-formal",
    "-khtml-simp-chinese-informal",
    "-khtml-trad-chinese-formal",
    "-khtml-trad-chinese-informal",
    "lower-greek",
    "-khtml-upper-greek",
    "lower-alpha",
    "lower-latin",
    "upper-alpha",
    "upper-latin",
    "hiragana",
    "katakana",
    "hiragana-iroha",
    "katakana-iroha",
    "-khtml-open-quote",
    "-khtml-close-quote",
    "inline",
    "block",
    "list-item",
    "run-in",
    "compact",
    "inline-block",
    "table",
    "inline-table",
    "table-row-group",
    "table-header-group",
    "table-footer-group",
    "table-row",
    "table-column-group",
    "table-column",
    "table-cell",
    "table-caption",
    "auto",
    "default",
    "context-menu",
    "help",
    "pointer",
    "progress",
    "wait",
    "cell",
    "crosshair",
    "text",
    "vertical-text",
    "alias",
    "copy",
    "move",
    "no-drop",
    "not-allowed",
    "e-resize",
    "n-resize",
    "ne-resize",
    "nw-resize",
    "s-resize",
    "se-resize",
    "sw-resize",
    "w-resize",
    "ew-resize",
    "ns-resize",
    "nesw-resize",
    "nwse-resize",
    "col-resize",
    "row-resize",
    "all-scroll",
    "ltr",
    "rtl",
    "capitalize",
    "uppercase",
    "lowercase",
    "visible",
    "collapse",
    "close-quote",
    "no-close-quote",
    "no-open-quote",
    "open-quote",
    "nowrap",
    "pre",
    "pre-wrap",
    "pre-line",
    "-khtml-nowrap",
    "break-word",
    "above",
    "absolute",
    "always",
    "avoid",
    "below",
    "bidi-override",
    "blink",
    "both",
    "crop",
    "cross",
    "embed",
    "hand",
    "hide",
    "higher",
    "invert",
    "landscape",
    "level",
    "line-through",
    "loud",
    "lower",
    "marquee",
    "mix",
    "overline",
    "portrait",
    "relative",
    "separate",
    "show",
    "static",
    "thick",
    "thin",
    "underline",
    "-khtml-normal",
    "-khtml-around-floats",
    "border-box",
    "content-box",
    "enabled",
    "disabled",
    "forwards",
    "backwards",
    "ahead",
    "reverse",
    "up",
    "down",
    "slow",
    "fast",
    "infinite",
    "slide",
    "alternate",
    "unfurl",
    "clip",
    "ellipsis",
    "padding-box",
    "border",
    "content",
    "padding",
    "contain",
    "cover",
    "evenodd",
    "nonzero",
    "before-edge",
    "text-before-edge",
    "central ",
    "after-edge",
    "text-after-edge",
    "ideographic",
    "alphabetic",
    "hanging",
    "mathematical ",
    "use-script",
    "no-change",
    "reset-size",
    "miter",
    "round",
    "bevel",
    "butt",
    "accumulate",
    "optimizeSpeed",
    "crispEdges",
    "geometricPrecision",
    "start",
    "end",
    "optimizeLegibility",
    "optimizeQuality",
    "sRGB",
    "linearRGB",
    "visiblePainted",
    "visibleFill",
    "visibleStroke",
    "painted",
    "fill",
    "stroke",
    "all",
    "lr-tb",
    "rl-tb",
    "tb-rl",
    "tb-lr",
    "lr",
    "rl",
    "tb",
    0
};
DOMString getValueName(unsigned short id)
{
    if (id >= CSS_VAL_TOTAL || id == 0) {
        return DOMString();
    } else {
        return DOMString(valueList[id]);
    }
}

