/* This file is automatically generated from cssproperties.in by makeprop, do not edit */
/* Copyright 1998 W. Bastian */

#ifndef CSSPROPERTIES_H
#define CSSPROPERTIES_H

DOM::DOMString getPropertyName(unsigned short id) KHTML_NO_EXPORT;

#define CSS_PROP_INVALID 0
#define CSS_PROP_MIN 1
#define CSS_PROP_BACKGROUND_COLOR 1
#define CSS_PROP_BACKGROUND_IMAGE 2
#define CSS_PROP_BACKGROUND_REPEAT 3
#define CSS_PROP_BACKGROUND_ATTACHMENT 4
#define CSS_PROP_BACKGROUND_POSITION 5
#define CSS_PROP_BACKGROUND_POSITION_X 6
#define CSS_PROP_BACKGROUND_POSITION_Y 7
#define CSS_PROP__KHTML_BACKGROUND_CLIP 8
#define CSS_PROP__KHTML_BACKGROUND_ORIGIN 9
#define CSS_PROP__KHTML_BACKGROUND_SIZE 10
#define CSS_PROP__KHTML_BORDER_TOP_RIGHT_RADIUS 11
#define CSS_PROP__KHTML_BORDER_BOTTOM_RIGHT_RADIUS 12
#define CSS_PROP__KHTML_BORDER_BOTTOM_LEFT_RADIUS 13
#define CSS_PROP__KHTML_BORDER_TOP_LEFT_RADIUS 14
#define CSS_PROP__KHTML_BORDER_RADIUS 15
#define CSS_PROP_BACKGROUND_CLIP 16
#define CSS_PROP_BACKGROUND_ORIGIN 17
#define CSS_PROP_BACKGROUND_SIZE 18
#define CSS_PROP_BORDER_TOP_RIGHT_RADIUS 19
#define CSS_PROP_BORDER_BOTTOM_RIGHT_RADIUS 20
#define CSS_PROP_BORDER_BOTTOM_LEFT_RADIUS 21
#define CSS_PROP_BORDER_TOP_LEFT_RADIUS 22
#define CSS_PROP_BORDER_RADIUS 23
#define CSS_PROP_BORDER_COLLAPSE 24
#define CSS_PROP_BORDER_SPACING 25
#define CSS_PROP__KHTML_BORDER_HORIZONTAL_SPACING 26
#define CSS_PROP__KHTML_BORDER_VERTICAL_SPACING 27
#define CSS_PROP_BORDER_TOP_COLOR 28
#define CSS_PROP_BORDER_RIGHT_COLOR 29
#define CSS_PROP_BORDER_BOTTOM_COLOR 30
#define CSS_PROP_BORDER_LEFT_COLOR 31
#define CSS_PROP_BORDER_TOP_STYLE 32
#define CSS_PROP_BORDER_RIGHT_STYLE 33
#define CSS_PROP_BORDER_BOTTOM_STYLE 34
#define CSS_PROP_BORDER_LEFT_STYLE 35
#define CSS_PROP_BORDER_TOP_WIDTH 36
#define CSS_PROP_BORDER_RIGHT_WIDTH 37
#define CSS_PROP_BORDER_BOTTOM_WIDTH 38
#define CSS_PROP_BORDER_LEFT_WIDTH 39
#define CSS_PROP_BOTTOM 40
#define CSS_PROP_CAPTION_SIDE 41
#define CSS_PROP_CLEAR 42
#define CSS_PROP_CLIP 43
#define CSS_PROP_COLOR 44
#define CSS_PROP_CONTENT 45
#define CSS_PROP_COUNTER_INCREMENT 46
#define CSS_PROP_COUNTER_RESET 47
#define CSS_PROP_CURSOR 48
#define CSS_PROP_DIRECTION 49
#define CSS_PROP_DISPLAY 50
#define CSS_PROP_EMPTY_CELLS 51
#define CSS_PROP_FLOAT 52
#define CSS_PROP_FONT_FAMILY 53
#define CSS_PROP_FONT_SIZE 54
#define CSS_PROP_FONT_STYLE 55
#define CSS_PROP_FONT_VARIANT 56
#define CSS_PROP_FONT_WEIGHT 57
#define CSS_PROP_HEIGHT 58
#define CSS_PROP_LEFT 59
#define CSS_PROP_LETTER_SPACING 60
#define CSS_PROP_LINE_HEIGHT 61
#define CSS_PROP_LIST_STYLE_IMAGE 62
#define CSS_PROP_LIST_STYLE_POSITION 63
#define CSS_PROP_LIST_STYLE_TYPE 64
#define CSS_PROP_MARGIN_TOP 65
#define CSS_PROP_MARGIN_RIGHT 66
#define CSS_PROP_MARGIN_BOTTOM 67
#define CSS_PROP_MARGIN_LEFT 68
#define CSS_PROP__KHTML_MARGIN_START 69
#define CSS_PROP__KHTML_MARQUEE 70
#define CSS_PROP__KHTML_MARQUEE_DIRECTION 71
#define CSS_PROP__KHTML_MARQUEE_INCREMENT 72
#define CSS_PROP__KHTML_MARQUEE_REPETITION 73
#define CSS_PROP__KHTML_MARQUEE_SPEED 74
#define CSS_PROP__KHTML_MARQUEE_STYLE 75
#define CSS_PROP_MAX_HEIGHT 76
#define CSS_PROP_MAX_WIDTH 77
#define CSS_PROP_MIN_HEIGHT 78
#define CSS_PROP_MIN_WIDTH 79
#define CSS_PROP_ORPHANS 80
#define CSS_PROP_OPACITY 81
#define CSS_PROP_OUTLINE_COLOR 82
#define CSS_PROP_OUTLINE_OFFSET 83
#define CSS_PROP_OUTLINE_STYLE 84
#define CSS_PROP_OUTLINE_WIDTH 85
#define CSS_PROP_OVERFLOW 86
#define CSS_PROP_OVERFLOW_X 87
#define CSS_PROP_OVERFLOW_Y 88
#define CSS_PROP_PADDING_TOP 89
#define CSS_PROP_PADDING_RIGHT 90
#define CSS_PROP_PADDING_BOTTOM 91
#define CSS_PROP_PADDING_LEFT 92
#define CSS_PROP__KHTML_PADDING_START 93
#define CSS_PROP_PAGE_BREAK_AFTER 94
#define CSS_PROP_PAGE_BREAK_BEFORE 95
#define CSS_PROP_PAGE_BREAK_INSIDE 96
#define CSS_PROP_POSITION 97
#define CSS_PROP_QUOTES 98
#define CSS_PROP_RIGHT 99
#define CSS_PROP_SIZE 100
#define CSS_PROP_SRC 101
#define CSS_PROP_TABLE_LAYOUT 102
#define CSS_PROP_TEXT_ALIGN 103
#define CSS_PROP_TEXT_DECORATION 104
#define CSS_PROP_TEXT_INDENT 105
#define CSS_PROP_TEXT_OVERFLOW 106
#define CSS_PROP_TEXT_SHADOW 107
#define CSS_PROP_TEXT_TRANSFORM 108
#define CSS_PROP_TOP 109
#define CSS_PROP_UNICODE_BIDI 110
#define CSS_PROP_UNICODE_RANGE 111
#define CSS_PROP_VERTICAL_ALIGN 112
#define CSS_PROP_VISIBILITY 113
#define CSS_PROP_WHITE_SPACE 114
#define CSS_PROP_WIDOWS 115
#define CSS_PROP_WIDTH 116
#define CSS_PROP_WORD_WRAP 117
#define CSS_PROP_WORD_SPACING 118
#define CSS_PROP_Z_INDEX 119
#define CSS_PROP_BACKGROUND 120
#define CSS_PROP_BORDER 121
#define CSS_PROP_BORDER_COLOR 122
#define CSS_PROP_BORDER_STYLE 123
#define CSS_PROP_BORDER_TOP 124
#define CSS_PROP_BORDER_RIGHT 125
#define CSS_PROP_BORDER_BOTTOM 126
#define CSS_PROP_BORDER_LEFT 127
#define CSS_PROP_BORDER_WIDTH 128
#define CSS_PROP_BOX_SIZING 129
#define CSS_PROP_FONT 130
#define CSS_PROP_LIST_STYLE 131
#define CSS_PROP_MARGIN 132
#define CSS_PROP_OUTLINE 133
#define CSS_PROP_PADDING 134
#define CSS_PROP_SCROLLBAR_BASE_COLOR 135
#define CSS_PROP_SCROLLBAR_FACE_COLOR 136
#define CSS_PROP_SCROLLBAR_SHADOW_COLOR 137
#define CSS_PROP_SCROLLBAR_HIGHLIGHT_COLOR 138
#define CSS_PROP_SCROLLBAR_3DLIGHT_COLOR 139
#define CSS_PROP_SCROLLBAR_DARKSHADOW_COLOR 140
#define CSS_PROP_SCROLLBAR_TRACK_COLOR 141
#define CSS_PROP_SCROLLBAR_ARROW_COLOR 142
#define CSS_PROP__KHTML_FLOW_MODE 143
#define CSS_PROP__KHTML_USER_INPUT 144
#define CSS_PROP_ALIGNMENT_BASELINE 145
#define CSS_PROP_BASELINE_SHIFT 146
#define CSS_PROP_CLIP_PATH 147
#define CSS_PROP_CLIP_RULE 148
#define CSS_PROP_COLOR_INTERPOLATION 149
#define CSS_PROP_COLOR_INTERPOLATION_FILTERS 150
#define CSS_PROP_COLOR_PROFILE 151
#define CSS_PROP_COLOR_RENDERING 152
#define CSS_PROP_DOMINANT_BASELINE 153
#define CSS_PROP_ENABLE_BACKGROUND 154
#define CSS_PROP_FILL 155
#define CSS_PROP_FILL_OPACITY 156
#define CSS_PROP_FILL_RULE 157
#define CSS_PROP_FILTER 158
#define CSS_PROP_FLOOD_COLOR 159
#define CSS_PROP_FLOOD_OPACITY 160
#define CSS_PROP_FONT_SIZE_ADJUST 161
#define CSS_PROP_FONT_STRETCH 162
#define CSS_PROP_GLYPH_ORIENTATION_HORIZONTAL 163
#define CSS_PROP_GLYPH_ORIENTATION_VERTICAL 164
#define CSS_PROP_IMAGE_RENDERING 165
#define CSS_PROP_KERNING 166
#define CSS_PROP_LIGHTING_COLOR 167
#define CSS_PROP_MARKER 168
#define CSS_PROP_MARKER_END 169
#define CSS_PROP_MARKER_MID 170
#define CSS_PROP_MARKER_START 171
#define CSS_PROP_MASK 172
#define CSS_PROP_POINTER_EVENTS 173
#define CSS_PROP_SHAPE_RENDERING 174
#define CSS_PROP_STOP_COLOR 175
#define CSS_PROP_STOP_OPACITY 176
#define CSS_PROP_STROKE 177
#define CSS_PROP_STROKE_DASHARRAY 178
#define CSS_PROP_STROKE_DASHOFFSET 179
#define CSS_PROP_STROKE_LINECAP 180
#define CSS_PROP_STROKE_LINEJOIN 181
#define CSS_PROP_STROKE_MITERLIMIT 182
#define CSS_PROP_STROKE_OPACITY 183
#define CSS_PROP_STROKE_WIDTH 184
#define CSS_PROP_TEXT_ANCHOR 185
#define CSS_PROP_TEXT_RENDERING 186
#define CSS_PROP_WRITING_MODE 187

#define CSS_PROP_TOTAL 188
const size_t maxCSSPropertyNameLength = 33;
#endif

